Casing

Trait Casing 

pub trait Casing<T: Display> {
    // Required methods
    fn to_case(&self, case: Case) -> String;
    fn is_case(&self, case: Case) -> bool;
}
Casing

Shared string case conversion surface retained locally so workspace crates do not depend on canic-utils for text casing.

Required Methods

fn to_case(&self, case: Case) -> String

Convert the receiver into the requested case form.

fn is_case(&self, case: Case) -> bool

Return whether the receiver is already in the requested case form.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T: Display> Casing<T> for T
where String: PartialEq<T>,